"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CollectionsService = void 0;
const Collection_1 = require("./Collection");
class CollectionsService {
    repository;
    constructor(deps) {
        this.repository = deps.repository;
    }
    async save(data) {
        const collection = await Collection_1.Collection.create(data);
        await this.repository.save(collection);
        return collection;
    }
    async edit(data) {
        const collection = await this.repository.getById(data.id);
        if (!collection) {
            return null;
        }
        Object.assign(collection, data);
        await this.repository.save(collection);
        return collection;
    }
    async getById(id) {
        return await this.repository.getById(id);
    }
    async getAll(options) {
        const collections = await this.repository.getAll(options);
        return {
            data: collections,
            meta: {
                pagination: {
                    page: 1,
                    pages: 1,
                    limit: collections.length,
                    total: collections.length,
                    prev: null,
                    next: null
                }
            }
        };
    }
    async destroy(id) {
        const collection = await this.getById(id);
        if (collection) {
            collection.deleted = true;
            await this.save(collection);
        }
        return collection;
    }
}
exports.CollectionsService = CollectionsService;
